@@ -7,7 +7,7 @@ package Tk::DirTree;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = '4.019';
+$VERSION = '4.021';
 
 use Tk;
 use Tk::Derived;
@@ -142,7 +142,7 @@ sub add_to_tree {
     my @args = (-image => $image, -text => $name);
     if( $parent ) {             # Add in alphabetical order.
         foreach my $sib ($w->infoChildren( $parent )) {
-	    use locale;
+	    use if $^O ne 'MSWin32', "locale"; # dumps core under Windows under some (japanese?) locales, see http://www.nntp.perl.org/group/perl.cpan.testers/2008/11/msg2550386.html
 	    my $sib8 = _fs_encode($sib);
 	    if ($sib8 gt $dir8) {
                 push @args, (-before => $sib);
@@ -192,6 +192,8 @@ sub dirnames {
 	$w->title($title);
 	$w->{ok} = 0; # flag: "1" means OK, "-1" means cancelled
 
+	$w->transient($w->Parent->toplevel);
+
 	# Create Frame widget before the DirTree widget, so it's always visible
 	# if the window gets resized.
 	my $f = $w->Frame->pack(-fill => "x", -side => "bottom");
