@@ -1,5 +1,6 @@
 
-package Plot;
+package # hide from CPAN indexer
+    Plot;
 
 # Class "Plot": constructor, methods, destructor, global class data,
 # etcetera.
@@ -12,7 +13,7 @@ package Plot;
 require 5.005_03;
 
 use vars qw/$VERSION @ISA/;
-$VERSION = '4.008'; # sprintf '4.%03d', q$Revision: #7 $ =~ /\D(\d+)\s*$/;
+$VERSION = '4.009'; # sprintf '4.%03d', q$Revision: #7 $ =~ /\D(\d+)\s*$/;
 
 use Tk::Frame;
 use base  qw/Tk::Frame/;
