@@ -5,20 +5,6 @@
 # distribution with permission.  It has been modified slightly to conform
 # to the widget demo standard.
 
-use vars qw/@FUNCTIONS @COLORS $NUM_COLORS $X_MIN $X_MAX $Y_MIN $Y_MAX
-	    $DX $DY $MIN_PXL $MAX_PXL $MARGIN $ALEN $ORIGINAL_CURSOR $CANV
-	    $DIALOG_ABOUT $DIALOG_USAGE $MBF $TEXT %ERRORS $VERSION $TOP/;
-
-sub plop {
-    my($demo) = @_;
-    $TOP = $MW->WidgetDemo(
-        -name             => $demo,
-        -text             => 'This demonstration allows you to enter arithmetic functions in the text widow and plot them.  The X and Y axes limits can be changed to scale the plotting canvas.',
-	-geometry_manager => 'pack',
-        -title            => 'Plot Continuous Functions y=f(x)',
-        -iconname         => 'plop',
-    );
-
 #!/usr/local/bin/perl -w
 #
 # plot_program - plot a series of continuous functions on a Perl/Tk Canvas.
@@ -26,7 +12,7 @@ sub plop {
 # Stephen O. Lidie, Lehigh University Computing Center, lusol@Lehigh.EDU
 # 96/01/27.
 #
-# Copyright (C) 1996 - 1996 Stephen O. Lidie. All rights reserved.
+# Copyright (C) 1996 - 1998 Stephen O. Lidie. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the same terms as Perl itself.
@@ -34,8 +20,8 @@ sub plop {
 require 5.002;
 use strict;
 use Tk;
-require Tk::Dialog;
-require Tk::LabEntry;
+use Tk::Dialog;
+use Tk::LabEntry;
 eval {require "plop.fnc";};	# user supplied math functions
 
 # Predeclare global subroutines and variables.
@@ -50,40 +36,41 @@ sub make_menubutton;
 sub plot_functions;
 sub update_functions;
 
-$VERSION = '1.0';
+my $VERSION = '1.0';
 
 # The default sample functions and limits, each in a different color.
 
-@FUNCTIONS = ('sin($x)', 'cos($x)', 'exp($x)', '$x', 'int($x)');
-@COLORS = qw(red green blue orange olivedrab cyan black salmon purple);
-$NUM_COLORS = scalar @COLORS;
-($X_MIN, $X_MAX, $Y_MIN, $Y_MAX) = (-10, 10, -10, 10);
-($DX, $DY) = ($X_MAX - $X_MIN, $Y_MAX - $Y_MIN);
+my (@FUNCTIONS) = ('sin($x)', 'cos($x)', 'exp($x)', '$x', 'int($x)');
+my (@COLORS) = qw(red green blue orange olivedrab magenta black salmon purple);
+my $NUM_COLORS = scalar @COLORS;
+my ($X_MIN, $X_MAX, $Y_MIN, $Y_MAX) = (-5, 5, -5, 5);
+my ($DX, $DY) = ($X_MAX - $X_MIN, $Y_MAX - $Y_MIN);
 
 # Declare constants that configure the plotting area: a square approximately
 # 500 pixels on a side, with left/right and top/bottom margins of 80 pixles
 # where we can paint axes labels.  With this layout there is a 340x340 area
 # available for graphs.
 
-$MIN_PXL = 0;		        # minimum Canvas pixel coordinate
-$MAX_PXL = 300;		        # maximum Canvas pixel coordinate
-$MARGIN = 80;		        # margin size, in pixels
-$ALEN = $MAX_PXL - 2 * $MARGIN;	# X/Y axes length, in pixels
+my $MIN_PXL = 0;		# minimum Canvas pixel coordinate
+my $MAX_PXL = 300;		# maximum Canvas pixel coordinate
+my $MARGIN = 80;		# margin size, in pixels
+my $ALEN = $MAX_PXL - 2 * $MARGIN; # X/Y axes length, in pixels
 
 # Declare Perl/Tk widgets and other data.
 
-#my $CANV;			# Canvas widget used for plotting functions
-#my $DIALOG_ABOUT;		# Dialog widget showing "About" information
-#my $DIALOG_USAGE;		# Dialog widget describing plot usage
-#my $MBF;			# Menubutton frame
-$ORIGINAL_CURSOR = ($TOP->configure(-cursor))[3]; # restore this cursor
-#my $TEXT;			# Text widget showing function definitions
+my $CANV;			# Canvas widget used for plotting functions
+my $DIALOG_ABOUT;		# Dialog widget showing "About" information
+my $DIALOG_USAGE;		# Dialog widget describing plot usage
+my $MBF;			# Menubutton frame
+my $MW = MainWindow->new;	# program's main window
+my $ORIGINAL_CURSOR = ($MW->configure(-cursor))[3]; # restore this cursor
+my $TEXT;			# Text widget showing function definitions
 
 # %ERRORS is a hash to collect eval() and -w errors.  The keys are the error
 # messages themselves and the values are the number of times a particular
 # error was detected.
 
-#my %ERRORS;
+my %ERRORS;
 
 # Begin main.
 
@@ -98,7 +85,7 @@ sub collect_errors {
 
     # Update the hash %ERRORS with the latest eval() error message.  Remove
     # the eval() line number (it's useless to us) to maintain a compact hash.
-    
+
     my($error) = @_;
 
     $error =~ s/eval\s+(\d+)/eval/;
@@ -113,7 +100,7 @@ sub display_coordinates {
     my($canvas) = @_;
 
     my $e = $canvas->XEvent;
-    my($canv_x, $canv_y) = ($e->x, $e->y); 
+    my($canv_x, $canv_y) = ($e->x, $e->y);
     my($x, $y);
     $x = $X_MIN + $DX * (($canv_x - $MARGIN) / $ALEN);
     $y = $Y_MAX - $DY * (($canv_y - $MARGIN) / $ALEN);
@@ -128,16 +115,16 @@ sub initialize_canvas {
 
     my($label_offset, $tick_length) = (20, 5);
 
-    $CANV = $TOP->Canvas(
-			-width  => $MAX_PXL + $MARGIN * 2, 
-			-height => $MAX_PXL, 
+    $CANV = $MW->Canvas(
+			-width  => $MAX_PXL + $MARGIN * 2,
+			-height => $MAX_PXL,
 			-relief => 'sunken',
 			);
     $CANV->pack;
     $CANV->Tk::bind('<Button-1>' => \&display_coordinates);
 
-    $CANV->create('text', 
-		  225, 25, 
+    $CANV->create('text',
+		  225, 25,
 		  -text => 'Plot Continuous Functions Of The Form y=f($x)',
 		  -fill => 'blue',
 		  );
@@ -147,67 +134,67 @@ sub initialize_canvas {
     # fall.  The axis limits are LabEntry widgets embedded in Canvas windows.
 
     $CANV->create('line',
-		  $MIN_PXL + $MARGIN, $MAX_PXL - $MARGIN, 
+		  $MIN_PXL + $MARGIN, $MAX_PXL - $MARGIN,
 		  $MAX_PXL - $MARGIN, $MAX_PXL - $MARGIN,
 		  );
 
     $CANV->create('window',
 		  $MIN_PXL + $MARGIN, $MAX_PXL - $label_offset,
-		  -window => $TOP->LabEntry(
+		  -window => $MW->LabEntry(
 					   -textvariable => \$X_MIN,
 					   -label => 'X Minimum',
 					   -width => 5,
 					   ),
 		  );
-    $CANV->create('line', 
+    $CANV->create('line',
 		  $MIN_PXL + $MARGIN, $MAX_PXL - $MARGIN - $tick_length,
 		  $MIN_PXL + $MARGIN, $MAX_PXL - $MARGIN + $tick_length,
 		  );
 
-    $CANV->create('window', 
+    $CANV->create('window',
 		  $MAX_PXL - $MARGIN, $MAX_PXL - $label_offset,
-		  -window => $TOP->LabEntry(
+		  -window => $MW->LabEntry(
 					   -textvariable => \$X_MAX,
 					   -label => 'X Maximum',
 					   -width => 5,
 					   ),
 		  );
-    $CANV->create('line', 
+    $CANV->create('line',
 		  $MAX_PXL - $MARGIN, $MAX_PXL - $MARGIN - $tick_length,
 		  $MAX_PXL - $MARGIN, $MAX_PXL - $MARGIN + $tick_length,
 		  );
 
-    # Create the line to represent the Y axis and label it.  Then label the 
+    # Create the line to represent the Y axis and label it.  Then label the
     # minimum and maximum Y values and draw tick marks to indicate where they
     # fall.  The axis limits are LabEntry widgets embedded in Canvas windows.
 
-    $CANV->create('line', 
-		  $MAX_PXL - $MARGIN, $MIN_PXL + $MARGIN, 
+    $CANV->create('line',
+		  $MAX_PXL - $MARGIN, $MIN_PXL + $MARGIN,
 		  $MAX_PXL - $MARGIN, $MAX_PXL - $MARGIN,
 		  );
 
-    $CANV->create('window', 
+    $CANV->create('window',
 		  $MAX_PXL + $label_offset, $MIN_PXL + $MARGIN,
-		  -window => $TOP->LabEntry(
+		  -window => $MW->LabEntry(
 					   -textvariable => \$Y_MAX,
 					   -label => 'Y Maximum',
 					   -width => 5,
 					   ),
 		  );
-    $CANV->create('line', 
+    $CANV->create('line',
 		  $MAX_PXL - $MARGIN - $tick_length, $MIN_PXL + $MARGIN,
 		  $MAX_PXL - $MARGIN + $tick_length, $MIN_PXL + $MARGIN,
 		  );
 
-    $CANV->create('window', 
+    $CANV->create('window',
 		  $MAX_PXL + $label_offset, $MAX_PXL - $MARGIN,
-		  -window => $TOP->LabEntry(
+		  -window => $MW->LabEntry(
 					   -textvariable => \$Y_MIN,
 					   -label => 'Y Minimum',
 					   -width => 5,
 					   ),
 		  );
-    $CANV->create('line', 
+    $CANV->create('line',
 		  $MAX_PXL - $MARGIN - $tick_length, $MAX_PXL - $MARGIN,
 		  $MAX_PXL - $MARGIN + $tick_length, $MAX_PXL - $MARGIN,
 		  );
@@ -218,15 +205,15 @@ sub initialize_dialogs {
 
     # Create all application Dialog objects.
 
-    $DIALOG_ABOUT = $TOP->Dialog(
+    $DIALOG_ABOUT = $MW->Dialog(
 				-title   => 'About',
-				-text    => 
+				-text    =>
 "plot_program $VERSION\n\n95/12/04\n\nThis program is described in the Perl/Tk column from Volume 1, Issue 1 of The Perl Journal (http://tpj.com/tpj), and is included in the Perl/Tk distribution with permission.",
 				-bitmap  => 'info',
 				-buttons => ['Dismiss'],
 				);
     $DIALOG_ABOUT->configure(-wraplength => '6i');
-    $DIALOG_USAGE = $TOP->Dialog(
+    $DIALOG_USAGE = $MW->Dialog(
 				-title   => 'Usage',
 				-buttons => ['Dismiss'],
 				);
@@ -241,8 +228,8 @@ sub initialize_functions {
 
     # Pack a spacer Frame and then display instructions in a Label widget.
 
-#    $TOP->Frame(-height => 10)->pack;
-    $TOP->Label(
+#    $MW->Frame(-height => 10)->pack;
+    $MW->Label(
 	       -text       => 'Enter your functions here',
 	       -foreground => 'blue',
 	       )->pack;
@@ -250,7 +237,7 @@ sub initialize_functions {
     # Create a Frame with a scrollable Text widget that displays the function
     # list, and a Button to initiate plot activities.
 
-    my $functions_frame = $TOP->Frame;
+    my $functions_frame = $MW->Frame;
     $functions_frame->pack;
     $TEXT = $functions_frame->Text(-height => 3);
     $TEXT->pack;
@@ -258,11 +245,11 @@ sub initialize_functions {
     $functions_frame->configure(-scrollbars => 'e');
     update_functions;
 
-    my $buttons_frame = $TOP->Frame;
+    my $buttons_frame = $MW->Frame;
     $buttons_frame->pack(-padx => 10, -pady => 5, -expand => 1, -fill => 'x');
     my @pack_attributes = qw(-side left -fill x -expand 1);
     $buttons_frame->Button(
-			   -text    => 'Plot', 
+			   -text    => 'Plot',
 			   -command => \&plot_functions,
 			   )->pack(@pack_attributes);
 
@@ -272,12 +259,12 @@ sub initialize_menus {
 
     # Create the Menubuttons and their associated Menu items.
 
-    $MBF = $TOP->Frame(-relief => 'raised', -borderwidth => 1);
+    $MBF = $MW->Frame(-relief => 'raised', -borderwidth => 1);
     $MBF->pack(-fill => 'x');
-	
+
     make_menubutton($MBF, 'File', 0, 'left',
 		    [
-		     ['Quit',  [$TOP => 'bell'],          0],
+		     ['Quit',  [$MW => 'bell'],          0],
 		    ],
 		   );
     make_menubutton($MBF, 'Help', 0, 'right',
@@ -291,22 +278,22 @@ sub initialize_menus {
 } # end initialize_menus
 
 sub make_menubutton {
-	
-    # Make a Menubutton widget; note that the Menu is automatically created.  
+
+    # Make a Menubutton widget; note that the Menu is automatically created.
     # If the label is '', make a separator.
 
     my($mbf, $mb_label, $mb_label_underline, $pack, $mb_list_ref) = @_;
 
     my $mb = $mbf->Menubutton(
-			       -text      => $mb_label, 
+			       -text      => $mb_label,
 			       -underline => $mb_label_underline,
 			      );
     my $mb_list;
     foreach $mb_list (@{$mb_list_ref}) {
 	$mb_list->[0] eq '' ? $mb->separator :
 	    $mb->command(
-			 -label     => $mb_list->[0], 
-			 -command   => $mb_list->[1], 
+			 -label     => $mb_list->[0],
+			 -command   => $mb_list->[1],
 			 -underline => $mb_list->[2],
 			 );
     }
@@ -320,11 +307,11 @@ sub plot_functions {
 
     my($x, $y, $canv_x, $canv_y) = (0, 0, 0, 0);
     $canv_x = $MIN_PXL + $MARGIN; # X minimum
-    $TOP->configure(-cursor => 'watch');
+    $MW->configure(-cursor => 'watch');
     $DX = $X_MAX - $X_MIN;	# update delta X
     $DY = $Y_MAX - $Y_MIN;	# update delta Y
     $CANV->delete('plot');	# erase all previous plots
-    
+
     # Fetch the newline-separated Text widget contents and update the function
     # list @FUNCTIONS.  Also update the Text widget with the new colors.
 
@@ -334,7 +321,7 @@ sub plot_functions {
 	push @FUNCTIONS, $_;
     }
     update_functions;
-    $TOP->idletasks;
+    $MW->idletasks;
 
     %ERRORS = ();
     local $SIG{'__WARN__'} = sub {collect_errors($_[0])};
@@ -355,7 +342,7 @@ ALL_X_VALUES:
 			  -fill => $COLORS[$_ % $NUM_COLORS],
 			  -tags => ['plot'],
 			  -text => '.',
-			  ) if $canv_y > $MIN_PXL + $MARGIN and 
+			  ) if $canv_y > $MIN_PXL + $MARGIN and
 			       $canv_y < $MAX_PXL - $MARGIN;
 	} # forend ALL_FUNCTIONS
 
@@ -363,8 +350,8 @@ ALL_X_VALUES:
 
     } # forend ALL_X_VALUES
 
-    $TOP->configure(-cursor => $ORIGINAL_CURSOR);
-    $TOP->idletasks;
+    $MW->configure(-cursor => $ORIGINAL_CURSOR);
+    $MW->idletasks;
 
     # Print all the eval() errors to alert the user of malformed functions.
 
@@ -392,6 +379,3 @@ sub update_functions {
     $TEXT->yview('end');
 
 } # end update_function_list
-
-} # end subroutine plop
-
