@@ -17,7 +17,7 @@
 #define _DEFAULT
 
 #if defined(__WIN32__) || defined(_WIN32) || \
-    defined(__CYGWIN__) || defined(__MINGW32__)
+    (defined(__CYGWIN__) && !defined(WINARCH_X)) || defined(__MINGW32__)
 #   include "tkWinDefault.h"
 #else
 #   if defined(MAC_OSX_TK)
