@@ -10,7 +10,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tkCanvPoly.c,v 1.9 2002/08/05 04:30:38 dgp Exp $
+ * RCS: @(#) $Id: tkCanvPoly.c,v 1.10.2.1 2003/05/11 00:57:09 hobbs Exp $
  */
 
 #include "tkPort.h"
@@ -275,6 +275,10 @@ CreatePolygon(interp, canvas, itemPtr, objc, objv)
     PolygonItem *polyPtr = (PolygonItem *) itemPtr;
     int i;
 
+    if (objc == 0) {
+	panic("canvas did not pass any coords\n");
+    }
+
     /*
      * Carry out initialization that is needed in order to clean
      * up after errors during the the remainder of this procedure.
@@ -377,9 +381,10 @@ PolygonCoords(interp, canvas, itemPtr, objc, objv)
 	}
     }
     if (objc & 1) {
-	Tcl_AppendResult(interp,
-		"odd number of coordinates specified for polygon",
-		(char *) NULL);
+	char buf[64 + TCL_INTEGER_SPACE];
+	sprintf(buf, "wrong # coordinates: expected an even number, got %d",
+		objc);
+	Tcl_SetResult(interp, buf, TCL_VOLATILE);
 	return TCL_ERROR;
     } else {
 	numPoints = objc/2;
@@ -1849,13 +1854,16 @@ PolygonToPostscript(interp, canvas, itemPtr, prepass)
     }
     if (polyPtr->numPoints==2) {
 	char string[128];
+	if (color == NULL) {
+	    return TCL_OK;
+	}
+
 	sprintf(string, "%.15g %.15g translate %.15g %.15g",
 		polyPtr->coordPtr[0], Tk_CanvasPsY(canvas, polyPtr->coordPtr[1]),
 		width/2.0, width/2.0);
 	Tcl_AppendResult(interp, "matrix currentmatrix\n",string,
 		" scale 1 0 moveto 0 0 1 0 360 arc\nsetmatrix\n", (char *) NULL);
-	if (Tk_CanvasPsColor(interp, canvas, color)
-		!= TCL_OK) {
+	if (Tk_CanvasPsColor(interp, canvas, color) != TCL_OK) {
 	    return TCL_ERROR;
 	}
 	if (stipple != None) {
