@@ -8,7 +8,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tkGrid.c,v 1.24 2002/08/05 04:30:38 dgp Exp $
+ * RCS: @(#) $Id: tkGrid.c,v 1.25 2002/10/10 21:07:51 pspjuth Exp $
  */
 
 #include "tkInt.h"
@@ -1173,9 +1173,11 @@ GridSlavesCommand(tkwin, interp, objc, objv)
 		slavePtr->row+slavePtr->numRows-1 < row)) {
 	    continue;
 	}
-	Tcl_ListObjAppendElement(interp, res,
-		Tcl_NewStringObj(Tk_PathName(slavePtr->tkwin), -1));
-    }
+	/*Tcl_ListObjAppendElement(interp, res,
+	  Tcl_NewStringObj(Tk_PathName(slavePtr->tkwin), -1));*/
+ 	Tcl_ListObjAppendElement(interp, res,
+				 LangWidgetObj(interp,slavePtr->tkwin));
+   }
     Tcl_SetObjResult(interp, res);
     return TCL_OK;
 }
@@ -2349,18 +2351,15 @@ Unlink(slavePtr)
     register Gridder *slavePtr;		/* Window to unlink. */
 {
     register Gridder *masterPtr, *slavePtr2;
-    GridMaster *gridPtr;	/* pointer to grid data */
 
     masterPtr = slavePtr->masterPtr;
     if (masterPtr == NULL) {
 	return;
     }
 
-    gridPtr = masterPtr->masterDataPtr;
     if (masterPtr->slavePtr == slavePtr) {
 	masterPtr->slavePtr = slavePtr->nextPtr;
-    }
-    else {
+    } else {
 	for (slavePtr2 = masterPtr->slavePtr; ; slavePtr2 = slavePtr2->nextPtr) {
 	    if (slavePtr2 == NULL) {
 		panic("Unlink couldn't find previous window");
@@ -2379,9 +2378,7 @@ Unlink(slavePtr)
 	*masterPtr->abortPtr = 1;
     }
 
-    if ((slavePtr->numCols+slavePtr->column == gridPtr->columnMax)
-	    || (slavePtr->numRows+slavePtr->row == gridPtr->rowMax)) {
-    }
+    SetGridSize(slavePtr->masterPtr);
     slavePtr->masterPtr = NULL;
 }
 
