@@ -36,7 +36,7 @@
 
 static int		DoConfig _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tk_Window tkwin, Tk_ConfigSpec *specPtr,
-			    Arg value, int valueIsUid, char *widgRec));
+			    Tcl_Obj * value, int valueIsUid, char *widgRec));
 static Tk_ConfigSpec *	FindConfigSpec _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tk_ConfigSpec *specs, CONST char *argvName,
 			    int needFlags, int hateFlags));
@@ -86,7 +86,7 @@ Tk_ConfigureWidget(interp, tkwin, specs, argc, argv, widgRec, flags)
 				 * may have TK_CONFIG_ARGV_ONLY set. */
 {
     register Tk_ConfigSpec *specPtr;
-    Arg value;			/* Value of option from database. */
+    Tcl_Obj * value;			/* Value of option from database. */
     int needFlags;		/* Specs must contain this set of flags
 				 * or else they are not considered. */
     int hateFlags;		/* If a spec contains any bits here, it's
@@ -222,11 +222,15 @@ Tk_ConfigureWidget(interp, tkwin, specs, argc, argv, widgRec, flags)
 		    return TCL_ERROR;
 		}
 	    } else {
-                if (specPtr->specFlags & TK_CONFIG_NULL_OK)
-		    LangSetDefault(&value,specPtr->defValue);
-                else
-		    LangSetString(&value,specPtr->defValue);
-		if (!LangNull(value) && !(specPtr->specFlags
+	        if (specPtr->defValue != NULL) {
+                    if (specPtr->specFlags & TK_CONFIG_NULL_OK)
+		    	LangSetDefault(&value,specPtr->defValue);
+                    else
+		    	LangSetString(&value,specPtr->defValue);
+		} else {
+		    value = NULL;
+		}
+		if ((value != NULL) && !(specPtr->specFlags
 			& TK_CONFIG_DONT_SET_DEFAULT)) {
 		    if (DoConfig(interp, tkwin, specPtr, value, 0, widgRec) !=
 			    TCL_OK) {
@@ -517,7 +521,7 @@ DoConfig(interp, tkwin, specPtr, value, valueIsUid, widgRec)
 		if (nullValue) {
 		    new = NULL;
 		} else {
-		    Arg tmp = LangCopyArg(value);
+		    Tcl_Obj * tmp = LangCopyArg(value);
 		    new = Tk_AllocFontFromObj(interp, tkwin, tmp);
 		    LangFreeArg(tmp, TCL_DYNAMIC);
 		    if (new == NULL) {
@@ -749,7 +753,7 @@ Tk_ConfigureInfo(interp, tkwin, specs, widgRec, argvName, flags)
     result = Tcl_NewListObj(0,NULL);
 
     for (specPtr = specs; specPtr->type != TK_CONFIG_END; specPtr++) {
-	Arg val;
+	Tcl_Obj * val;
 
 	if ((argvName != NULL) && (specPtr->argvName != argvName)) {
 	    continue;
@@ -787,7 +791,7 @@ Tk_ConfigureInfo(interp, tkwin, specs, widgRec, argvName, flags)
  *--------------------------------------------------------------
  */
 
-static Arg
+static Tcl_Obj *
 FormatConfigInfo(interp, tkwin, specPtr, widgRec)
     Tcl_Interp *interp;			/* Interpreter to use for things
 					 * like floating-point precision. */
@@ -1080,9 +1084,9 @@ Tk_FreeOptions(specs, widgRec, display, needFlags)
 		}
 		break;
             case TK_CONFIG_LANGARG:
-		if (*((Arg *) ptr) != NULL) {
-		    LangFreeArg(*((Arg *) ptr),TCL_DYNAMIC);
-		    *((Arg *) ptr) = NULL;
+		if (*((Tcl_Obj * *) ptr) != NULL) {
+		    LangFreeArg(*((Tcl_Obj * *) ptr),TCL_DYNAMIC);
+		    *((Tcl_Obj * *) ptr) = NULL;
 		}
 		break;
             case TK_CONFIG_SCALARVAR:
