@@ -9,7 +9,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tclInterp.c,v 1.18 2002/09/03 16:31:32 msofer Exp $
+ * RCS: @(#) $Id: tclInterp.c,v 1.20.2.2 2003/05/12 22:35:40 dgp Exp $
  */
 
 #include "tclInt.h"
@@ -461,7 +461,9 @@ Tcl_InterpObjCmd(clientData, interp, objc, objv)
 		    Tcl_WrongNumArgs(interp, 2, objv, "?-safe? ?--? ?path?");
 		    return TCL_ERROR;
 		}
-		slavePtr = objv[i];
+		if (i < objc) {
+		    slavePtr = objv[i];
+		}
 	    }
 	    buf[0] = '\0';
 	    if (slavePtr == NULL) {
@@ -1089,6 +1091,18 @@ TclPreventAliasLoop(interp, cmdInterp, cmd)
          * the source alias, we have a loop.
 	 */
 
+	if (Tcl_InterpDeleted(nextAliasPtr->targetInterp)) {
+	    /*
+	     * The slave interpreter can be deleted while creating the alias.
+	     * [Bug #641195]
+	     */
+
+	    Tcl_AppendStringsToObj(Tcl_GetObjResult(interp),
+		    "cannot define or rename alias \"",
+		    Tcl_GetString(aliasPtr->namePtr),
+		    "\": interpreter deleted", (char *) NULL);
+	    return TCL_ERROR;
+	}
 	cmdNamePtr = nextAliasPtr->objPtr;
 	aliasCmd = Tcl_FindCommand(nextAliasPtr->targetInterp,
                 Tcl_GetString(cmdNamePtr),
@@ -1153,12 +1167,11 @@ AliasCreate(interp, slaveInterp, masterInterp, namePtr, targetNamePtr,
 {
     Alias *aliasPtr;
     Tcl_HashEntry *hPtr;
-    int new;
     Target *targetPtr;
     Slave *slavePtr;
     Master *masterPtr;
-    int i;
     Tcl_Obj **prefv;
+    int new, i;
 
     aliasPtr = (Alias *) ckalloc((unsigned) (sizeof(Alias)
             + objc * sizeof(Tcl_Obj *)));
@@ -1176,13 +1189,17 @@ AliasCreate(interp, slaveInterp, masterInterp, namePtr, targetNamePtr,
 	Tcl_IncrRefCount(objv[i]);
     }
 
+    Tcl_Preserve(slaveInterp);
+    Tcl_Preserve(masterInterp);
+
     aliasPtr->slaveCmd = Tcl_CreateObjCommand(slaveInterp,
 	    Tcl_GetString(namePtr), AliasObjCmd, (ClientData) aliasPtr,
 	    AliasObjCmdDeleteProc);
 
-    if (TclPreventAliasLoop(interp, slaveInterp, aliasPtr->slaveCmd) != TCL_OK) {
+    if (TclPreventAliasLoop(interp, slaveInterp,
+	    aliasPtr->slaveCmd) != TCL_OK) {
 	/*
-	 * Found an alias loop!  The last call to Tcl_CreateObjCommand made
+	 * Found an alias loop!	 The last call to Tcl_CreateObjCommand made
 	 * the alias point to itself.  Delete the command and its alias
 	 * record.  Be careful to wipe out its client data first, so the
 	 * command doesn't try to delete itself.
@@ -1196,19 +1213,21 @@ AliasCreate(interp, slaveInterp, masterInterp, namePtr, targetNamePtr,
 	    Tcl_DecrRefCount(objv[i]);
 	}
 
-        cmdPtr = (Command *) aliasPtr->slaveCmd;
-        cmdPtr->clientData = NULL;
-        cmdPtr->deleteProc = NULL;
-        cmdPtr->deleteData = NULL;
-        Tcl_DeleteCommandFromToken(slaveInterp, aliasPtr->slaveCmd);
+	cmdPtr = (Command *) aliasPtr->slaveCmd;
+	cmdPtr->clientData = NULL;
+	cmdPtr->deleteProc = NULL;
+	cmdPtr->deleteData = NULL;
+	Tcl_DeleteCommandFromToken(slaveInterp, aliasPtr->slaveCmd);
 
-        ckfree((char *) aliasPtr);
+	ckfree((char *) aliasPtr);
 
-        /*
-         * The result was already set by TclPreventAliasLoop.
-         */
+	/*
+	 * The result was already set by TclPreventAliasLoop.
+	 */
 
-        return TCL_ERROR;
+	Tcl_Release(slaveInterp);
+	Tcl_Release(masterInterp);
+	return TCL_ERROR;
     }
 
     /*
@@ -1260,6 +1279,9 @@ AliasCreate(interp, slaveInterp, masterInterp, namePtr, targetNamePtr,
     aliasPtr->targetEntryPtr = hPtr;
 
     Tcl_SetObjResult(interp, namePtr);
+
+    Tcl_Release(slaveInterp);
+    Tcl_Release(masterInterp);
     return TCL_OK;
 }
 
@@ -1424,7 +1446,7 @@ AliasObjCmd(clientData, interp, objc, objv)
 #define ALIAS_CMDV_PREALLOC 10
     Tcl_Interp *targetInterp;
     Alias *aliasPtr;
-    int result, prefc, cmdc;
+    int result, prefc, cmdc, i;
     Tcl_Obj **prefv, **cmdv;
     Tcl_Obj *cmdArr[ALIAS_CMDV_PREALLOC];
     aliasPtr = (Alias *) clientData;
@@ -1452,6 +1474,9 @@ AliasObjCmd(clientData, interp, objc, objv)
 
     Tcl_ResetResult(targetInterp);
 
+    for (i=0; i<cmdc; i++) {
+	Tcl_IncrRefCount(cmdv[i]);
+    }
     if (targetInterp != interp) {
 	Tcl_Preserve((ClientData) targetInterp);
 	result = Tcl_EvalObjv(targetInterp, cmdc, cmdv, TCL_EVAL_INVOKE);
@@ -1460,6 +1485,9 @@ AliasObjCmd(clientData, interp, objc, objv)
     } else {
 	result = Tcl_EvalObjv(targetInterp, cmdc, cmdv, TCL_EVAL_INVOKE);
     }
+    for (i=0; i<cmdc; i++) {
+	Tcl_DecrRefCount(cmdv[i]);
+    }
 
     if (cmdv != cmdArr) {
 	ckfree((char *) cmdv);
