@@ -336,7 +336,7 @@ static void Tix_ImageItemDisplay(pixmap, gc, iPtr, x, y, width, height, flags)
     }
 
     TixGetColorDItemGC(iPtr, &backGC, &foreGC, flags);
-    TixpStartSubRegionDraw(itPtr->ddPtr->display, pixmap, foreGC,
+    TixpStartSubRegionDraw(itPtr->ddPtr, pixmap, foreGC,
 	    &subReg, 0, 0, x, y, width, height,
 	    itPtr->size[0], itPtr->size[1]);
     TixDItemGetAnchor(itPtr->stylePtr->anchor, x, y, width, height,
