@@ -1,18 +1,10 @@
-#ifndef NULL
-#    define NULL 0
-#endif 
-#include <X11/X.h>
-#include <X11/Xlib.h>
-#include <stdio.h>
-#include <tkInt.h>
-#include <tkPort.h>
+#include "tk.h"
 
 /*
  * Undocumented Xlib internal function
  */
 
-int
-_XInitImageFuncPtrs(XImage *image)
+int _XInitImageFuncPtrs(XImage *image)
 {
     return 0;
 }
@@ -202,7 +194,7 @@ XQueryColor(display, colormap, def_in_out)
     XQueryColors(display, colormap, def_in_out, 1);
 }
 
-#if 0 
+#if 0
 void
 XQueryColors(display, colormap, defs_in_out, ncolors)
     Display* display;
@@ -263,7 +255,7 @@ void
 XSetCommand(display, w, args, argc)
     Display* display;
     Window w;
-    char** args;
+    CONST char** args;
     int argc;
 {
 }
@@ -376,7 +368,7 @@ XmbLookupString(ic, event, buffer_return, bytes_buffer, keysym_return,
 {
     return 0;
 }
-
+
 int
 XGetWindowProperty(display, w, property, long_offset, long_length, delete,
 	req_type, actual_type_return, actual_format_return, nitems_return,
@@ -403,3 +395,4 @@ XGetWindowProperty(display, w, property, long_offset, long_length, delete,
 }
 
 
+
